@@ -151,7 +151,7 @@ class EventsRuleToStepFunction(
             log_group_props=log_group_props,
         )
 
-        jsii.create(EventsRuleToStepFunction, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="eventsRule")
